
import { alert, goLink, isEmptyObject, retrieval } from "@/common/common";
import Popup from "@/components/popup";
import { Button, Image, Text, Textarea, View } from "@tarojs/components"
import Taro, { chooseMedia } from "@tarojs/taro";
import { realNameUpdateApi } from "@/api/user";
import { companyDetailApi, companyUpdateApi } from "@/api/company"
import { memo, useCallback, useEffect, useRef, useState } from "react"
import "./index.scss"
import ModifyModal from "./components/ModifyModal";
import useLogin from "@/use/useLogin";
import { useSelector } from "@/reducers/hooks";

export default ()=>{
  const { getPhoneNumber, getAdminUserInfo } = useLogin();
	const {adminUserInfo} = useSelector(state => state.userInfo);
	// 用户信息
  useEffect(()=>{
    setFormData({
      ...adminUserInfo as any
    })
  }, [adminUserInfo])
  // 表单数据
  const [formData, setFormData] = useState({
    user_name: "麦兜"
  });
  // 昵称修改保存
	const { fetchData: realNameUpdateFetch } = realNameUpdateApi();
  const rules = {
    user_name: [{
      message: "请输入"
    }]
  }
  const {fetchData: saveFetch} = companyUpdateApi();
  const handleTextareaSave = async (text, type)=>{
    retrieval({text},rules).then(async ()=>{
      let result;
      if(type=="Ickname"){
        result = await realNameUpdateFetch({real_name: text});
      }else{
        result = saveFetch({company_name: text});
      }
      if(result.success){
        getAdminUserInfo();
        alert.success("保存成功");
      }else{
        alert.none(result.msg);
      }
    }).catch(message=>{
      alert.none(message);
    })
  }
  // Taro.eventCenter.on('message:detail', (message) => console.log(message))
  // 面面跳转
  const onNavigate = (url:string)=>{
    goLink(url);
  }
  // 肖像编辑
  const handleSelectRortrait = ()=>{
    chooseMedia({
      count: 1,
      mediaType: ["image"],
      success(ev){
        console.log(ev);
        
      }
    })
  }
	const mGetPhoneNumber = (ev)=>{
		if(ev.detail?.code){
			getPhoneNumber(ev.detail.code);
		}else{
			alert.none("绑定失败!");
		}
	}
  const ModifyIcknameEl = useRef(null);
  const ModifyCompanyNameEl = useRef(null);

  return (
    <View className="user-edit">
      <View onClick={handleSelectRortrait} className="user-edit-portrait">
        <Image src="https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fimg.jj20.com%2Fup%2Fallimg%2F1113%2F052420110515%2F200524110515-2-1200.jpg&refer=http%3A%2F%2Fimg.jj20.com&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=auto?sec=1652840455&t=6d2fd53931578ef6e213a929a77d059c"/>
        <View>点击编辑头像</View>
      </View>
      <View className="user-edit-content">
        <View className="user-edit-content-title"><Text/> 个人资料</View>
        <UserEditList onClick={()=>(ModifyIcknameEl.current as any).setModalShow(true)} data={(formData as any)?.user_name} label="昵称" placeholder="请输入" icon=""/>
        <UserEditList label="手机号" placeholder="去绑定" icon="">
          {((formData as any)?.phone)?<View className="user-edit-content-phone">
            <View>{(formData as any)?.phone}</View>
            <Text>已绑定</Text>
           </View>:
           <Button className="user-edit-content-bindphone" openType="getPhoneNumber" onGetPhoneNumber={mGetPhoneNumber}>去绑定</Button>
          }
        </UserEditList>
      </View>
      <View className="user-edit-content">
        <View className="user-edit-content-title"><Text/> 组织资料</View>
        <UserEditList onClick={()=>(ModifyCompanyNameEl.current as any).setModalShow(true)} data={(formData as any)?.company_name} label="名称" placeholder="待绑定" icon=""/>
        <UserEditList onClick={()=>onNavigate("/pages/company/index")} label="类型" placeholder="完善公司/组织信息" icon=""/>
        <UserEditList onClick={()=>onNavigate("/pages/certification/index")} label="我的认证" placeholder="待绑定" icon="">
          <View className="user-edit-content-company">
            <Text className="iconfont "/> 未认证
          </View>
        </UserEditList>
        <UserEditList onClick={()=>onNavigate("/pages/weightList/index")} label="创建人" data={(formData as any)?.founder_user_name} placeholder="完善公司/组织信息" icon=""/>
      </View>
      <Button hoverClass="none" className="user-edit-logout">退出当前账号</Button>

      <ModifyModal title="修改昵称" ref={ModifyIcknameEl} value={(formData as any)?.user_name} save={(value)=>handleTextareaSave(value, "Ickname")}/>
      <ModifyModal title="修改名称" ref={ModifyCompanyNameEl} value={(formData as any)?.company_name} save={(value)=>handleTextareaSave(value, "companyName")}/>
    </View>
  )
}

// 列表
const UserEditList = memo((props:any)=>{
  return (
    <View onClick={props.onClick} className="user-edit-list">
      <View className="user-edit-list-left">
        {props.label}
      </View>
      <View className="user-edit-list-right">
        <View>
          {
            props.children?props.children:
            props.data?props.data:
            <View className="user-edit-list-right-placeholder">{props.placeholder}</View>
          }
        </View>
        <Text className="iconfont icon-a-moreback"></Text>
      </View>
    </View>
  )
})
